<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_PT">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Existe vida para além do navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versão %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é Software Livre mas o seu desenvolvimento leva tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;Faça um donativo&lt;/a&gt; para suportar o desenvolvimento continuado do%2.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Reporte erros e envie as suas ideias para%1</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icon criado por %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto contribuído por%1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Suporte a proxy HTTP contribuído por%1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traduzido por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Lançado nos termos da &lt;a href=&apos;&quot;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Tudo o que sempre quis saber sobre o %1 e nunca se atreveu a perguntar</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/seg</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restante</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Transferência</numerusform>
            <numerusform>%n Transferências</numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Isto é apenas uma versão de demonstração de %1.</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Apenas pode transferir vídeos mais curtos que %1 minuto(s) de forma a testar a funcionalidade de transferência.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Transfira a versão completa</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translatorcomment>soa melhor assim :)</translatorcomment>
        <translation>Mudar pasta de destino...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Escolha a pasta de destino da transferência</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>A pasta de destino da transferência foi actualizada.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>A pasta de transferência actual irá manter-se na mesma pasta.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>A transferir para: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Transferências</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translatorcomment>vale a pena traduzir?</translatorcomment>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Iniciar/Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translatorcomment>vale a pena traduzir?</translatorcomment>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Parar assim que terminar o vídeo ou música corrente</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Próximo vídeo/música</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Vídeo/música anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silêncio</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Retroceder</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>A pesquisar...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar mais %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Sem vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Sem mais vídeos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Para a reprodução e voltar à vista de pesquisa</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>S&amp;altar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar para o próximo vídeo</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar reprodução</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Ecrã &amp;Completo</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir para ecrã completo</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;Compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Esconder a lista de reprodução e a barra de ferramentas</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Abrir a página do &amp;Youtube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir para a página do Youtube do vídeo e parar a reprodução</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copiar o &amp;link do Youtube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar o link do Youtube do vídeo actual para a área de transferência</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copiar o &amp;URL da emissão de vídeo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar o URL da emissão de vídeo actual para a área de transferência</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Remover os vídeos seleccionados da lista de reprodução</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover para &amp;Cima</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover para cima os vídeos seleccionados na lista de reprodução</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover para &amp;Baixo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover para baixo os vídeos seleccionados na lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">&amp;Limpar pesquisas recentes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Limpar o histório de pesquisa. Não pode ser desfeito.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adeus</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sítio &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Internet</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Fazer uma &amp;doação</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor suporte o desenvolvimento continuado do %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informação sobre %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar o volume</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicação</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Prima %1 para aumentar o volume, %2 para reduzi-lo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>A abrir %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erro fatal:%1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erro:%1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproduzir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Retomar a reprodução</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Sair do Ecrã &amp;Completo</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante:%1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume a :%1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>O volume está silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>O volume não está silenciado</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Definição de vídeo máxima estabelecida em %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>A sua privacidade está agora assegurada</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Transferências</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Mostar detalhes sobre a transferência de vídeos</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Transferência</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Transferir o vídeo actual</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Deseja sair %1 com uma transferência activa?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Se fechar %1, a transferência irá ser cancelada.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Fechar e cancelar a transferência</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Espere que a transferência termine</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Transferência completa</translation>
    </message>
    <message>
        <source>&amp;Clear recent searches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Mais relevantes</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Mais recentes</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Mais vistos</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Pode agora colar o link do Youtube noutra aplicação</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Pode agora colar o URL da emissão de vídeo noutra aplicação</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>O link será válido apenas por algum tempo.</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation type="obsolete">Está a assistir a &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Isto é apenas uma versão de demonstração de %1.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Permite testes a aplicacção e verificar como funciona.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Transfira a versão completa</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Transferir: %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Erro de rede: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizações</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) ? %4</source>
        <translation type="obsolete">%1 de %2 (%3) ? %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>A preparar</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completo</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Parado</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Parar a transferência</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Mostrar em %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Abrir pasta anterior</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Recomeçar a transferência</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation type="obsolete">Insira uma pesquisa para começar a assitir a vídeos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Assistir</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Pesquisas recentes</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Uma nova versão do %1 está disponível. Por favor &lt;a href=&apos;%2&apos;&gt;actualize para a versão %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Acomode-se confortavelmente</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished">Transfira a versão completa</translation>
    </message>
    <message>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Erro de rede: %1 para %2</translation>
    </message>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
